pub struct Address {
pub name: String,
pub attention: Option<String>,
pub address_line1: String,
pub address_line2: Option<String>,
pub address_line3: Option<String>,
pub city: Option<String>,
pub county: Option<String>,
pub district: Option<String>,
pub state_or_region: String,
pub postal_code: Option<String>,
pub country_code: String,
pub phone: Option<String>,
}Expand description
Address : Address of the party.
Fields
name: StringThe name of the person, business or institution at that address.
attention: Option<String>The attention name of the person at that address.
address_line1: StringFirst line of the address.
address_line2: Option<String>Additional address information, if required.
address_line3: Option<String>Additional address information, if required.
city: Option<String>The city where the person, business or institution is located.
county: Option<String>The county where person, business or institution is located.
district: Option<String>The district where person, business or institution is located.
state_or_region: StringThe state or region where person, business or institution is located.
postal_code: Option<String>The postal code of that address. It conatins a series of letters or digits or both, sometimes including spaces or punctuation.
country_code: StringThe two digit country code. In ISO 3166-1 alpha-2 format.
phone: Option<String>The phone number of the person, business or institution located at that address.